@@ -1,10 +1,8 @@
 import os
 
 import boto3
-from prefect import task
 
 
-@task
 def change_key(location: str, old_key: str, new_key: str) -> None:
     if location[:5] == "s3://":
         change_key_on_s3(location[5:], old_key, new_key)
