@@ -1,10 +1,7 @@
 import os
 from datetime import datetime
 
-from prefect import task
 
-
-@task
 def make_key(*subkeys: str) -> str:
     key = os.path.join(*subkeys)
 
