@@ -1,10 +1,8 @@
 import os
 
 import boto3
-from prefect import task
 
 
-@task
 def remove_key(location: str, key: str) -> None:
     if location[:5] == "s3://":
         remove_key_on_s3(location[5:], key)
